#ifndef COIN_SOVERTEXATTRIBUTEELEMENT_H
#define COIN_SOVERTEXATTRIBUTEELEMENT_H

/**************************************************************************\
 * Copyright (c) Kongsberg Oil & Gas Technologies AS
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 
 * Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\**************************************************************************/

#include <Inventor/elements/SoAccumulatedElement.h>
#include <Inventor/elements/SoSubElement.h>
#include <Inventor/tools/SbPimplPtr.h>

class SoState;
class SoMField;
class SoVertexAttributeData;
class SoVertexAttributeElementP;

class COIN_DLL_API SoVertexAttributeElement : public SoAccumulatedElement {
  typedef SoAccumulatedElement inherited;
  SO_ELEMENT_HEADER(SoVertexAttributeElement);

public:
  static void initClass(void);
  virtual void init(SoState * state);

  virtual void push(SoState * state);
  static void add(SoState * const state, SoVertexAttributeData * attribdata);
                  
  static const SoVertexAttributeElement * getInstance(SoState * const state);
  unsigned int getNumAttributes(void) const;

  typedef const char * Key;
  typedef SoVertexAttributeData * Type;
  typedef void AttributeApplyFunc(const Key & key, const Type & obj, void * closure);
  void applyToAttributes(AttributeApplyFunc * func, void * closure) const;

protected:
  virtual ~SoVertexAttributeElement();

  virtual void addElt(SoVertexAttributeData * attribdata);

private:
  // needed by SbPimplPtr
  SoVertexAttributeElement(const SoVertexAttributeElement & rhs); // N/A
  SoVertexAttributeElement & operator = (const SoVertexAttributeElement & rhs); // N/A

  SbPimplPtr<SoVertexAttributeElementP> pimpl;
};

#endif // COIN_SOVERTEXATTRIBUTEELEMENT_H
